
/* Generated by glib-mkenums.rb ($Id$) */ 

#ifndef __GOBJECT_INTROSPECTION_ENUM_TYPES_H__
#define __GOBJECT_INTROSPECTION_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "/usr/include/gobject-introspection-1.0/girepository.h" */
GType g_i_repository_load_flags_get_type (void);
#define G_TYPE_I_REPOSITORY_LOAD_FLAGS (g_i_repository_load_flags_get_type())
GType g_i_repository_error_get_type (void);
#define G_TYPE_I_REPOSITORY_ERROR (g_i_repository_error_get_type())

/* enumerations from "/usr/include/gobject-introspection-1.0/gitypes.h" */
GType g_i_info_type_get_type (void);
#define G_TYPE_I_INFO_TYPE (g_i_info_type_get_type())
GType g_i_transfer_get_type (void);
#define G_TYPE_I_TRANSFER (g_i_transfer_get_type())
GType g_i_direction_get_type (void);
#define G_TYPE_I_DIRECTION (g_i_direction_get_type())
GType g_i_scope_type_get_type (void);
#define G_TYPE_I_SCOPE_TYPE (g_i_scope_type_get_type())
GType g_i_type_tag_get_type (void);
#define G_TYPE_I_TYPE_TAG (g_i_type_tag_get_type())
GType g_i_array_type_get_type (void);
#define G_TYPE_I_ARRAY_TYPE (g_i_array_type_get_type())
GType g_i_field_info_flags_get_type (void);
#define G_TYPE_I_FIELD_INFO_FLAGS (g_i_field_info_flags_get_type())
GType g_iv_func_info_flags_get_type (void);
#define G_TYPE_IV_FUNC_INFO_FLAGS (g_iv_func_info_flags_get_type())
GType g_i_function_info_flags_get_type (void);
#define G_TYPE_I_FUNCTION_INFO_FLAGS (g_i_function_info_flags_get_type())

G_END_DECLS

#endif /* __GOBJECT_INTROSPECTION_ENUM_TYPES_H__ */

/* Generated data ends here */

